/********************************************************************
 * FileName:        adc_monitor.c
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 ********************************************************************/

#include "adc_monitor.h"

unsigned char m_selectedAdcChanel = 0;

/********************************************************************
 * Function:        	runAdcMonitor
 *
 * Overview:        	ADC monitoring
 *******************************************************************/
void runAdcMonitor()
{
        //If the ADC is available
        if (!GO_nDONE)//not busy? (+sppReq priority)
        {
            //Part 1: Check the last converted value
            int sum = CHAR_CONCAT_TO_UINT(ADRESH, ADRESL);
            //Do the averaging (AVG index 0 -> avg val)
#if AVG_SIZE > 1
            for (int i = 0; i < AVG_SIZE-1; i++)
            {
                int valTmp = m_adcValueList[m_selectedAdcChanel][i+1];
                m_adcValueList[m_selectedAdcChanel][i] = valTmp;
                sum += valTmp;
            }
#endif
            sum += m_adcValueList[m_selectedAdcChanel][0];
            sum = sum/(AVG_SIZE+1);
            //Place the AVG result in index 0
            m_adcValueList[m_selectedAdcChanel][AVG_SIZE-1] = sum;

            //Increase the selected chanel to that one has to be converted
            //and launch a new conversion.
            m_selectedAdcChanel = (m_selectedAdcChanel + 1) % ADC_MON_CHAN_SIZE;
            SET_ADC_CHANEL(m_adcChannelMonitorList[m_selectedAdcChanel]);
            GO_nDONE = 1;
        
        }
}

/********************************************************************
 * Function:        	adcDirectRead
 *
 * Input:        	char channel: Selected channel (See part datasheet or
 *                      V_MCP1911X.h)
 * Output:              Value from th ADC
 *
 * Overview:        	ADC read function. This function is blocking the current
 *                      program until a value from the ADC has been readed
 *******************************************************************/
int adcDirectRead(char channel) {
    while (GO_nDONE); //Not allready is used?
    SET_ADC_CHANEL(channel); //Set channel
    NOP();
    NOP();
    NOP();
    NOP();
    GO_nDONE = 1; //Start conversion
    while (GO_nDONE); //Wait conversion
    return CHAR_CONCAT_TO_UINT(ADRESH, ADRESL); //Read value
}


