/********************************************************************
 * FileName:        adc_monitor.h
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 ********************************************************************/

#ifndef ADC_MONITOR_H
#define	ADC_MONITOR_H

#ifdef	__cplusplus
extern "C" {
#endif

#include "pic.h"
#include "V_MCP1911X.h"
#include "macro.h"

//******************************************************************************
// ADC PART
//******************************************************************************
//ADC channel selection
#define ADC_VIN_ANA 0b00000 //(analog voltage proportional to VIN)
#define ADC_VREGREF 0b00001 //(reference voltage for VREG output)
#define ADC_OV_REF 0b00010 //(reference for over voltage comparator)
#define ADC_UV_REF 0b00011 //(reference for under voltage comparator)
#define ADC_VBGR 0b00100 //(bandgap reference)
#define ADC_INT_VREG 0b00101 //(internal version of the VREG load voltage)
#define ADC_CRT 0b00110 //(voltage proportional to the current in the inductor)
#define ADC_VZC 0b00111 //(an internal ground, Voltage for Zero Current)
#define ADC_DEMAND 0b01000 //(input to current loop, output of demand mux)
#define ADC_DTYCYCL_ANA 0b01001 //(analog voltage proportional to duty cycle)
#define ADC_TMP_ANA 0b01010 //(analog voltage proportional to temperature)
#define ADC_ANA_IN 0b01011 //(demanded current from the remote master)
#define ADC_DCI 0b01100 //(dc inductor valley current)
#define ADC_GPA0 0b10000 //(i.e. ADDR1)
#define ADC_GPA1 0b10001 //(i.e. ADDR0)
#define ADC_GPA2 0b10010 //(i.e. Temperature Sensor Input)
#define ADC_GPA3 0b10011 //(i.e. Tracking Voltage)
#define ADC_GPB1 0b10100
#define ADC_GPB2 0b10101
#define ADC_GPB4 0b10110
#define ADC_GPB5 0b10111

#define ADC_VAL_VIN_ANA 0
#define ADC_VAL_INT_VREG 1
#define ADC_VAL_TMP_ANA 2
#define ADC_VAL_CRT 3

#define ADC_MON_CHAN_SIZE 4
#define AVG_SIZE 4

#define SET_ADC_CHANEL(x) ADCON0 = (ADCON0 & 0x83) | (x << 2)

void runAdcMonitor();
int adcDirectRead(char channel);

char m_adcChannelMonitorList[ADC_MON_CHAN_SIZE] =
{
    ADC_VIN_ANA, //VIN
    ADC_INT_VREG , //VOUT
    ADC_TMP_ANA,  //Temperature
    ADC_DCI  //Current
};
unsigned int m_adcValueList[ADC_MON_CHAN_SIZE][AVG_SIZE];

/* External memory locations **************************************************/
extern volatile unsigned int ADRES @ 0x01C; //For program memory efficient
                                            //  reading of the 10b value

#ifdef	__cplusplus
}
#endif

#endif	/* ADC_MONITOR_H */

