/********************************************************************
 * FileName:        flash_rw.c
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 ********************************************************************/


#include "flash_rw.h"



/********************************************************************
 * Function:        	writeFlash
 *
 * Inputs:        	unsigned char addrMSB : Calibration word address MSB
 *                      unsigned char addrLSB : Calibration word address LSB
 * Output:              char * buf : Readed Calibration word (2 bYtes)
 *
 * Overview:        	Self write value into the flash
 *******************************************************************/
void writeFlash(unsigned int addr, unsigned int value[]) {

    addr += MEM_OFFSET;
    unsigned char contscr = 0; //this variable is a counter

    while (contscr < WRITE_SIZE) {
        PMADRH = HIGH_BYTE(addr); //Load initial data address
        PMADRL = LOW_BYTE(addr) + contscr; //Load initial data address
        PMDATH = 0x1A; // Load second data byte into upper
        PMDATL = (char) LOW_BYTE(value[contscr]); //Load first data byte into lower
        PMCON1bits.WREN = 1; //enabling the write
        PMCON2 = 0x55; //required write sequence
        PMCON2 = 0xAA; //required write sequence
        PMCON1bits.WR = 1; //begin write
        NOP(); //Required to transfer data to the buffer
        NOP(); //registers
        contscr++; //Increment address
        PMCON1bits.WREN = 0; //disabling the write
    }
    contscr = 0; //erase the counter
}

/********************************************************************
 * Function:        	readFlash
 *
 * Inputs:        	unsigned char addrMSB : Calibration word address MSB
 *                      unsigned char addrLSB : Calibration word address LSB
 * Output:              char * buf : Readed Calibration word (2 Bytes)
 *
 * Overview:        	Read Factory Calibration value for the part
 *******************************************************************/
void readFlash(unsigned int addr, unsigned char * buf, char calib) {
    if (!calib)
        addr += MEM_OFFSET;
    PMADRH = HIGH_BYTE(addr);
    PMADRL = LOW_BYTE(addr);
    CALSEL = calib;
    RD = 1;
    NOP();
    NOP();
    *buf = PMDATL;
    *(buf + 1) = (PMDATH & 0x3F);
    CALSEL = 0;
    return;
}

