/********************************************************************
 * FileName:        init_part.c
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 * 1.001                10.21.2014  Adding factory ADC calibration reading from flash for MCP19118/9 device.
 ********************************************************************/


#include "init_part.h"

void initPart()
{
    // SET SWITCHING FREQUENCY
    PWMPHL = V_PWMPHL; //phase shift
    PR2 = V_PR2; //frequency
    T2CON = V_T2CON; //enable timer.

    //(VOUT UV protection should not be enable during soft start if enabled)
    // ENABLE PERIPHERAL
    PE1 = V_PE1;
    BUFFCON = V_BUFFCON;
    ABECON = V_ABECON & NOT_OV_UV_MASK; //set later OOV OUV when OV set
    ATSTCON = V_ATSTCON;
    //Vout default state
    PWMRL = 0x00;
    HIDIS = 1; //HIDRV, 1=disable, 0=enable
    PUEN = 1; //+Vsen pull-up, 1=enable, 0=disable

    //Read calibration data and set into the appropriate register
    PMADRH = 0x20; CALSEL = 1;
    PMADRL = 0x80; RD = 1; NOP(); NOP(); DOVCAL = PMDATH; OSCCAL = PMDATL;
    PMADRL = 0x81; RD = 1; NOP(); NOP(); TTACAL = PMDATH; BGRCAL = PMDATL;
    PMADRL = 0x82; RD = 1; NOP(); NOP(); VROCAL = PMDATH; ZROCAL = PMDATL;
    PMADRL = 0x88; RD = 1; NOP(); NOP(); calib.D2VOG = PMDAT; //Available only for MCP19118/19
    PMADRL = 0x89; RD = 1; NOP(); NOP(); calib.D2VOO = PMDATL; //Available only for MCP19118/19

    //LOAD PROTECTION REGISTERS VALUE (but not enabled here)
    OUVCON = V_OUVCON;
    OOVCON = V_OOVCON;
    OCCON = V_OCCON;
    VINLVL = V_VINLVL;

    //OPTION
    OPTION_REG = DEF_OPTION_REG;
    //Timer 1 config
    T1CON = DEF_T1CON;

    // SWITCHING DEAD TIME SETTING
    DEADCON = V_DEADCON;

    // COMPENSATION SETTING
    CMPZCON = V_CMPZCON;
    SLPCRCON = V_SLPCRCON;
    SLVGNCON = V_SLVGNCON;

    // CURRENT SENSE SETTING
    CSGSCON = V_CSGSCON;
    VZCCON = V_VZCCON;
    CSDGCON = V_CSDGCON;

    // ADC SETTING
    ADCON0 = DEF_ADCON0;
    ADCON1 = DEF_ADCON1;

    // SET OUTPUT VOLTAGE
    OVFCON = V_OVFCON;
    //Wait for VIN UV gone
    PIR2bits.VINIF = 0;
    while (VINIF == 1)
    PIR2bits.VINIF = 0;

    //Init IO CONFIG
    //Set all pins as input, expect GPA 0 and 2 which are as output and GPA1 which depends of the output mode (SLAVE/MASTER)
    const unsigned char MLTPH = V_BUFFCON >> 5;
    if ((MLTPH == 2) || (MLTPH == 4))
        TRISGPA = 0xFA; //Slave output mode
    else
        TRISGPA = 0xF8; //Master/stand alone output mode

    TRISGPB = 0xFF;
    //Set all pin as digital IO
    ANSELA = 0;
    ANSELB = 0;
    WPUGPA = 0x0;
    WPUGPB = 0x0;

    //IO pin special setting
    EN_PIN_WPU = 1; //weak pull up enable
    EN_PIN_IO = 1; //input mode
    EN_PIN = 0; //set output latch to '0'
    EN_PIN_INT_EN = 0; //interrupt disable

    SMBALERT_PIN = 0;
    SMBALERT_PIN_IO = 1;

    //CLEAR INTERRUPT FLAGS
    PIR1 = 0x00;
    PIR2 = 0x00;

    // INTERRUPT SETTING
    PIE1 = DEF_PIE1;
    INTCON = DEF_INTCON;
}

