/********************************************************************
 * FileName:        macro.h
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 ********************************************************************/

#define HIGH_BYTE(x)           (unsigned char)(x>>8)
#define LOW_BYTE(x)           (unsigned char)(x & 0xFF)
#define CHAR_CONCAT_TO_UINT(msb,lsb) (unsigned int)((msb << 8) | lsb);


//******************************************************************************
// Varius initialisatsions values
//******************************************************************************
#define NOT_OV_UV_MASK        0X3F
//TIMER 1 CONFIG
#define DEF_T1CON         0X12
//INTERRUPT CONFIG
#define DEF_INTCON        0XC0
#define  DEF_PIE1         0xBD
#define  DEF_PIE2         0xFE


//******************************************************************************
// PMBus PART
//******************************************************************************

//ADC SETUP
#define DEF_ADCON0        0X11
#define DEF_ADCON1        0X60
#define DEF_SSPSTAT       0x00
#define DEF_OPTION_REG    0x04

//MSSP SETUP
#define DEF_SSPCON1       0x26
#define DEF_SSPCON2       0x00
#define DEF_SSPCON3       0x05

#define DEF_OV_UV_RECOVERY_TIME 0x3FF
#define DEF_OV_UV_DELAY_TIME 0xFF

#define DEF_MAIN_LOOP_REQ_INIT 0xFF

//dev internal ID
#define DEV_MCP19111 0
#define DEV_MCP19110 1
#define DEV_MCP19119 2
#define DEV_MCP19118 3

/* Delays *********************************************************************/
#define DLY_POR 250 //Power-on reset
#define DLY_SS   20 //Soft start step
#define DLY_SSC   2 //Soft start step for calibration
#define DLY_CAL  40 //Settling period for calibration


/* Data Structures ************************************************************/
typedef struct {
  unsigned char OVC;    //Coarse output voltage setting
  unsigned char OVF;    //Fine output voltage setting + DAC enable
  unsigned int  OV;     //Output voltage scaled by 2^8 (PMBus linear format w/o
                        // the exponent, -8)
} POLSettings_T;

typedef struct {
  unsigned int  D2VOG; //ADC to output voltage gain
  signed   char D2VOO; //                      offset
} CALIB_T;

#define VOUT_LINEAR (V_VOUT_COMMAND_H << 8) | V_VOUT_COMMAND_L

///* Memory location definitions ************************************************/
//extern volatile unsigned int PMDAT @ 0x194; //For program memory efficient
//                                            //  reading of program memory data
