/********************************************************************
 * FileName:        output_mngt.h
 * Dependencies:    See INCLUDES section below
 * Processor:       MCP19111
 * Compiler:        XC8 v1.11
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement:
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") for its PICmicro Microcontroller is intended and
 * supplied to you, the Company's customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in vsiolation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *********************************************************************
 *
 * Version              Date        Comment
 * 1.000                02.03.2013  Initial release
 ********************************************************************/
#ifndef OUTPUT_MNGT_H
#define	OUTPUT_MNGT_H

#ifdef	__cplusplus
extern "C" {
#endif


#include "pic.h"
#include "V_MCP1911X.h"
#include "adc_monitor.h"
#include "macro.h"

CALIB_T calib;

#define VOUT_MAX 3840/4
#define VOUT_CODE_FROM_PMB_OVERFLOW(x) (x > VOUT_MAX)
#define VOUT_CODE_FROM_PMB(x) (x/4)
#define VOUT_GET_MANTISSA(x) (int)(*(x+1) << 8 | (*x))
#define VOUT_EN 0x80


#define ON_OFF_ALWAYS_ON_B  0x10
#define ON_OFF_PIN_ON       0x04

#define OPERATION_ENABLE    0x80
#define OPERATION_NORMAL    0b110000

#define RESP_TRIED_MASK     0x38
#define GET_RESP_TRIED(x)   x & RESP_TRIED_MASK
#define SUB_RESP_TRIED(x)   x=x-8
#define GET_RESP_MODE(x)    x>>6

#define RESTART_IF_FAULT_AGAIN 1
#define DIRECT_RESTART_IF_FAULT 2
#define DIRECT_STOP 3

#define OPERATION_COMMAND 0X01
#define ON_OFF_CONFIG_COMMAND 0X02
#define VOUT_OV_FAULT_RESPONSE_COMMAND 0X41
#define VOUT_UV_FAULT_RESPONSE_COMMAND 0X45
#define IOUT_OC_FAULT_RESPONSE_COMMAND 0X47

void switchOffOutput(void);
void softStopOutput(void);
void restoreOutput(void);
void voutRampTarget(void);
void checkOutputRange(unsigned char * pmb_mem, unsigned char * reg);
void checkEnPin(void);

unsigned char OPERATION[1]={V_OPERATION};
unsigned char ON_OFF_CONFIG[1]={V_ON_OFF_CONFIG};
unsigned char VOUT_OV_FAULT_RESPONSE[1]={V_VOUT_OV_FAULT_RESPONSE};
unsigned char VOUT_UV_FAULT_RESPONSE[1]={V_VOUT_UV_FAULT_RESPONSE};
unsigned char IOUT_OC_FAULT_RESPONSE[1]={V_IOUT_OC_FAULT_RESPONSE};



unsigned char m_OVCCON_target = 0;
unsigned char m_TMR1H;//Variable allowing update soft start in dbg
unsigned char m_TMR1L;//Variable allowing update soft start in dbg
unsigned int m_voutADCTarget;

#ifdef	__cplusplus
}
#endif

#endif	/* OUTPUT_MNGT_H */

